#ifndef event_hh
#define event_hh

#include "TObject.h"
#include "TRef.h"
#include <vector>

class Hit;
class Track;

/**
 * Event class
 * Has two vectors with pointers to the Hits and Tracks which were created in this event.
 * (Has ownership of the track and hits).
 * A pointer to the primary track is stored in a dedicated TRef.
 */
class Event : public TObject{

public:
  Event();
  ~Event();

  //Add pointer to a hit
  void AddHit(Hit* hit);
  //Get pointer to the vector of hits
  std::vector<Hit*>* GetHits();
  //Add pointer to a track
  void AddTrack(Track* track);
  //Get pointer to the vector of tracks
  std::vector<Track*>* GetTracks();
  //Add primary track
  void AddPrimaryTrack(Track* track);
  //Get pointer to primary track
  Track* GetPrimaryTrack();

  void Reset();

private:
  std::vector<Hit*> Hits;//Vector with all hits of this event
  std::vector<Track*> Tracks;//Vector with all tracks of this event
  TRef PrimaryTrack;//TRef to the primary track

  ClassDef(Event, 1);

};

#endif
