#include "Event.hh"
#include "Track.hh"
#include "Hit.hh"

#include "TFile.h"
#include "TTree.h"
#include "TRandom3.h"

int main(int, char**){

  TFile *file = new TFile("test.root", "RECREATE", "test file");
  TTree *tree = new TTree("tree", "test tree");
  tree->SetDirectory(file);
  tree->SetAutoSave(1000);
  tree->SetCacheSize(10000000);

  Event *myEvent = new Event();
  tree->Branch("event", &myEvent, 1600, 99);
  tree->BranchRef();

  TRandom3 rnd;

  for(int i = 0; i<10; ++i){
    //Create random number of tracks
    int nbTrack = rnd.Poisson(10);
    for(int trackID = 0; trackID < nbTrack; ++trackID){
      //Fill each track with random data
      Track* tmpTrack = new Track();
      double trackData = rnd.Gaus();
      tmpTrack->AddData(trackData);
      //Create for each track a random number of hits
      int nbHits = rnd.Poisson(10);
      for(int hitID = 0; hitID < nbHits; ++hitID){
	//Fill each hit with random data
	Hit* tmpHit = new Hit();
	double hitData = rnd.Gaus();
	tmpHit->AddData(hitData);
	//Link each hit with its parent track
	tmpHit->AddTrack(tmpTrack);
	//Add each hit to its parent track
	tmpTrack->AddHit(tmpHit);
	//Add each hit to the event
	myEvent->AddHit(tmpHit);
      }
      //Add each track to the event
      if(trackID==0){
	//If it was the first track, it is the "primary track"
	myEvent->AddPrimaryTrack(tmpTrack);
      }else{
	myEvent->AddTrack(tmpTrack);
      }
    }
    //Store the event
    tree->Fill();
    //Clear the event for new data
    myEvent->Reset();
  }

  //Write data to disk and close file
  file->Write();
  file->Close();

  return 0;
}
